****************************************************************************
*Project Name: Politicizing Administration
*Part: Chapter 5
*Filename:
*Date: March 13, 2006
*Data: 06politicization.dta
*Data2: economictvfinal.dta
*Data2(old): 06timevarycv.dta
*
*Summary: This batch file seeks to read in the data, describe it, 
*separate out the cases that are problematic for data analysis as 
*described in Politicization Over Time.doc, and execute the analysis 
*described in Chapter 5 of the book.
*
*General Notes: The data I use here are described in an accompanying codebook, 
*Politicization Over Time.doc and Time-varying Covariates.doc.  
*There are several robustness checks worth 
*considering when analyzing this data. First, some agencies are commissions 
*and have more appointees for that reason. Second, some agencies have SES 
*employees and others do not.  Similarly, some have their own personnel 
*systems and some do not. Third, the catch-all "Other" category for each 
*large department or agency is the most variable and users would be advised 
*to estimate models with and without these observations.  Fourth, measures of 
*politicization that are percentages based upon either the number of managers 
*or the number of employees vary quite a bit over all but smaller agencies 
*vary a lot more.  Fifth, all models should control
*for a change in the number of managers.  The number of managers changes 
*quite substantially in some cases.  Sixth, different cases are used for 
*different types of appointees.  You can include more with Schedule C, than
*NC SES, and PAS, respectively.  This batch file will have to be run
*several times, each time adjusting the commands for which cases to include
*or exclude.
*
*Data Notes: This version of the data looks like all the other bureauwithindagencies 
*datasets except that this includes measures of agency preferences as described in 
*Clinton and Lewis 2007. Specifically, it includes the means from 26 expert 
*surveys, the number of raters, and the estimates w/o covariates based upon
*23 ratings.
*
*****************************************************************************
*First, I need to do some housekeeping.
set memory 64000
set l 72
set level 95
set matsize 800

*Now I will read in the data and combine the agency data with the time-varying covariates.
use 071206politicization
joinby year using economictvfinal.dta

*Given the concerns listed in the codebook, I drop some cases from the analysis.

**For all analysis of politicization.

*Family Support Administration (HHS) and Office of Human Development (HHS)
drop if agencyid==35100&year>1990|agencyid==35110&year>1990
*Defense Commissary Agency (DEF)
drop if agencyid==10150&year<1992
*Alcohol and Tobacco Tax and Trade Bureau (TREAS)
drop if agencyid==60030&year>2002
*Information Technology Service (GSA)
drop if agencyid==30060&year>1995
*Tricare Support Office (DEF)
drop if agencyid==10100&year>1998
*American Battle Monuments Commission
drop if agencyid==20
*Office of Governmentwide Policy (GSA)
drop if agencyid==30070&year<1996
*Office of Thrift Supervision (TREAS)
drop if agencyid==60020&year>1990&year<1994

**For analyses including SES.

*Office of the Comptroller of the Currency (TREAS)
drop if agencyid==60100&year>1989
*Federal Bureau of Investigation (DOJ)
drop if agencyid==15000&year==1988
generate lntotses=ln(totalses+1)

**For analyses including PAS.

*US Arms Control and Disarmament Agency
drop if agencyid==30
*Executive Office of the US Attorneys (DOJ)
drop if agencyid==15060
*Other for Department of Education
drop if agencyid==2500000
*Foreign Agricultural Service (USDA)
drop if agencyid==1060&year>1995&year<2004
*U.S. Marshals Service (DOJ)
drop if agencyid==15050&year>2001
*Office of Educational Research & Improvement/Inst for Ed Sciences (ED)
drop if agencyid==25040&year<1993
*Office of Postsecondary Education (ED)
drop if agencyid==25020&year<1993
*Broadcasting Board of Governors
drop if agencyid==480&year>1999
*National Foundation on the Arts and Humanities
drop if agencyid==60&year==2005
*National Science Foundation
drop if agencyid==560&year>1996
*Department of the Navy
drop if agencyid==640&year>1998

**For analyses including accessions and separations.

*Financial Crimes Enforcement Network (TREAS)
*drop if agencyid==60090&year==2003
*Bureau of Immigration and Customs Enforcement (DHS)
*drop if agencyid==40040&year==2003
*Bureau of Customs and Border Protection (DHS)
*drop if agencyid==40060&year==2003
*Social Security Administration (HHS/IND)
*drop if agencyid==770&year==1995
*drop if agencyid==770&year==1996

*For analyses including counts or percentages of professionals.
drop if agencyid==210&year>1996

summarize
tsset agencyid year

*Now I generate the total number of appointees and the percent of managers that are appointed. I add 1 appointee
*to each agency so that it is easier to take logs. To verify the robustness of the method I also
*create these same variables without adding 1.

generate totalpa=noncareerses+schc+pas
generate lnschcp=ln(schc+1)
generate lnschc=ln(schc)
generate lnnc=ln(noncareer)
generate lnncp=ln(noncareer+1)
generate lnnc2=ln(noncareer+otherses)
generate lnnc2p=ln(noncareer+otherses+1)
generate lnpas=ln(pas)
generate lnpasp=ln(pas+1)
generate management=(totalemp-nonmanagers)
generate managers2=managers+1
generate politpct=totalpa/management
generate schcpct=schc/management
generate ncpct=noncareerses/management
generate paspct=pas/management
generate pcpct=(noncareerses+schc)/management
generate sesncpct=noncareerses/(noncareerses+careerses)
generate sncpct2=(noncareerses+otherses)/totalses

*Now I generate the percent of employees that are professional
generate profpct=prof/totalemp
generate techpct=tech/totalemp


*Now I generate employment and management numbers
generate lnemp=ln(totalemp)
generate lnman=ln(management+1)
generate lnman2=ln(managers2)

*Now I generate variables to measure turnover in the Senior Executive Service
*generate totalsep=separation50+separation55+separation60+separation65
*generate totalacc=accession50+accession55+accession60+accession65
*generate sesseppct=totalsep/totalses
*generate sesaccpct=totalacc/totalses
*generate sescaseppct=separation50/totalses

*Now and indicator for "Other" category
generate otherbureau=0
replace otherbureau=1 if agencyid>100000

*Now I identify those agencies with departments over them

generate independent=0
replace independent=1 if departmentid==0
replace independent=1 if departmentid==5
replace independent=1 if otherbureau==1

*Now I generate variables to analyze the change in appointee percentages.

sort agencyid year
by agencyid: generate dpol=politpct-politpct[_n-1]
by agencyid: generate dschc=schcpct-schcpct[_n-1]
by agencyid: generate dncpct=ncpct-ncpct[_n-1]
by agencyid: generate dpaspct=paspct-paspct[_n-1]
by agencyid: generate dsesnc=sesnc-sesnc[_n-1]
by agencyid: generate dsnc2=snc-snc[_n-1]
by agencyid: generate dpcpct=pcpct-pcpct[_n-1]
by agencyid: generate dtotalpa=totalpa-totalpa[_n-1]
by agencyid: generate dmana=management-management[_n-1]

*Now I generate year of term indicators and other measures of within term
*dynamics.

tab tyear, generate (ty)
generate lntyear=ln(tyear)
generate tenureyear=tyear
replace tenureyear=tyear+4 if secterm==1
generate lnteny=ln(tenureyear)

**Analysis

*I will start with some simple summary statistics for the analysis in Chapter 5.  

*First, I need to list those agencies that are the most politicized in 2005 by size.  I need to first
*generate a variable that is the average of an agency's employment over the years so that I can
*separate them into small, medium, large, and very large.

sort agencyid
by agencyid: egen meanemp=mean(emp)
by agencyid: egen seniorex=max(totalses)

generate small=0
replace small=1 if meanemp<=500

generate medium=0
replace medium=1 if meanemp>500&meanemp<=5000

generate large=0
replace large=1 if meanemp>5000&meanemp<=20000

generate vlarge=0
replace vlarge=1 if meanemp>20000

summarize small medium large vlarge
generate size=0
replace size=1 if medium==1
replace size=2 if large==1
replace size=3 if vlarge==1


*Now that I have the agencies segregated into groups based upon size I will see which are most politicized in each category.
*sort polit
*list department bureau pas noncareerses schc totalemp management polit if year==2005&small==1&polit>.75&polit~=.&bureau~="Other"
*list department bureau pas noncareerses schc totalemp management polit if year==2005&medium==1&polit>.10&polit~=.&bureau~="Other"
*list department bureau pas noncareerses schc totalemp management polit if year==2005&large==1&polit>.02&polit~=.&bureau~="Other"
*list department bureau pas noncareerses schc totalemp management polit if year==2005&vlarge==1&polit>.001&polit~=.&bureau~="Other"

*Now I will list some agencies that have no appointees at all in September of 2005.
*sort emp
*list department bureau totalemp management polit if year==2005&small==1&polit==0&polit~=.&bureau~="Other"
*list department bureau totalemp management polit if year==2005&medium==1&polit==0&polit~=.&bureau~="Other"
*list department bureau totalemp management polit if year==2005&large==1&polit==0&polit~=.&bureau~="Other"
*list department bureau totalemp management polit if year==2005&vlarge==1&polit==0&polit~=.&bureau~="Other"

**This section includes the commands for the list of agencies included in Tables 1-3 in Chapter 5.********
*Second, I need to list those agencies that got politicized under President Clinton and President Bush
*drop if year<1992
*drop if year>1996
*drop if year>1992&year<1996
*sort agencyid year
*by agencyid: generate dpol2=polit-polit[_n-1]
*by agencyid: generate dpas2=pas-pas[_n-1]
*by agencyid: generate dnc2=noncareer-noncareer[_n-1]
*by agencyid: generate lntotses=ln(noncareerses+careerses)
*by agencyid: generate dschc2=schc-schc[_n-1]
*by agencyid: generate dtotal2=totalpa-totalpa[_n-1]

*sort dpol2
*list department bureau dpol2 polit dpas2 dnc2 dschc2 management emp pas noncareerses schc if dpol2~=.&dpol2>0&dtotal2>2&bureau~="Other"
*more

*drop if year<2000
*drop if year>2004
*drop if year>2000&year<2004

*sort agencyid year
*by agencyid: generate dpol2=polit-polit[_n-1]
*by agencyid: generate dpas2=pas-pas[_n-1]
*by agencyid: generate dnc2=noncareer-noncareer[_n-1]
*by agencyid: generate dschc2=schc-schc[_n-1]
*by agencyid: generate dtotal2=totalpa-totalpa[_n-1]
*sort dpol2
*list department bureau dpol2 polit dpas2 dnc2 dschc2 management emp pas noncareerses schc if dpol2~=.&dpol2>0&dtotal2>2&bureau~="Other"
**********************************************************************************************************

*Now I create some variables to help identify the agencies with the highest
*percentage of professionals and the biggest changes in professional percentage
*during this time period. The same commands can be used for the percentage
*of employees engaged in technical occupations.

by agencyid: egen maxprof=max(profpct)
by agencyid: egen minprof=min(profpct)
by agencyid: generate diffprof1=profpct-maxprof
by agencyid: generate diffprof2=profpct-minprof

list agencyid bureau profpct if year==1988 & maxprof==profpct&profpct~=.


**Generate Control Variables for Regressions***************************************************************

*First a variable for Republican president.
generate reppres=0
replace reppres=1 if dempres==0

generate replib=reppres*liberal
generate repcon=reppres*conservative

generate demlib=dempres*liberal
generate demcon=dempres*conservative

*Now agency indicators
*tab agencyid, generate(a)

*An indicator for whether or not an agency has its own personnel system.
generate notitle5=0
replace notitle5=1 if agencyid==1060|agencyid==1250|agencyid==45020|agencyid==15000|agencyid==60020|agencyid==65050|agencyid==360|agencyid==630|agencyid==680
*Federal Aviation Administration
replace notitle5=1 if agencyid==55000&year>1996
*Internal Revenue Service
replace notitle5=1 if agencyid==60040&year>2001

*Now a more generous interpretation
*Transportation Security Administration
*replace notitle5=1 if agencyid==40050
*Department of Homeland Security
*replace notitle5=1 if departmentid==7
*Department of Defense
*replace notitle5=1 if departmentid==3&year>2002

*Now an indicator for whether the agency has Senior Executive Service or not. Some agencies never have SES personnel, either
*career or appointed.  
generate sen=0
replace sen=1 if seniorex==0

*Now president indicators
generate bush1=0
replace bush1=1 if year<1993
generate clinton=0
replace clinton=1 if year>1992&year<2001
generate bush2=0
replace bush2=1 if year>2000

*Now I create the measure of agency preferences that uses point estimates rather than
*indicators.

generate aprefs=aprefrateonly+2.091

generate aprefsq=aprefs^2
generate reppref=aprefs*reppres

*Now by president rather than party. Here I interact president indicators with agency
*preference measures.

generate b1aprefs=bush1*aprefs
generate b1lib=bush1*liberal
generate b1con=bush1*conservative

generate claprefs=clinton*aprefs
generate cllib=clinton*liberal
generate clcon=clinton*conservative

generate b2aprefs=bush2*aprefs
generate b2lib=bush2*liberal
generate b2con=bush2*conservative

generate demdept=0
replace demdept=1 if aprefs<2.2963

generate repdept=0
replace repdept=1 if aprefs>2.2963

generate repdem=reppres*demdept
generate demrep=dempres*repdept

generate reprep=reppres*repdept
generate demdem=dempres*demdept

*Now ideology measures
generate prdist=abs(hmed-prescom)
generate chdist=abs(hmed-smed)
sort agencyid year

generate prespref=prescom*aprefs

*First for pictures to show that I am right.
*graph bar dpol if small==1, over(partch, relabel (1 "No Party Change"   2 "Party Change")) ytitle (Change in Appointee Percentage)  title(Small Agencies)
*graph bar dpol if medium==1, over(partch, relabel (1 "No Party Change"   2 "Party Change")) ytitle (Change in Appointee Percentage)  title(Medium-Sized Agencies)
*graph bar dpol if large==1, over(partch, relabel (1 "No Party Change"   2 "Party Change")) ytitle (Change in Appointee Percentage)  title(Large Agencies)
*graph bar dpol if vlarge==1, over(partch, relabel (1 "No Party Change"   2 "Party Change")) ytitle (Change in Appointee Percentage)  title(Very Large Agencies)

*sort year
*by year: summarize dpol
*by year: summarize dtotalpa
*by year: summarize dpol if small==1
*by year: summarize dpol if medium==1
*by year: summarize dpol if large==1
*by year: summarize dpol if vlarge==1

*sort partch
*by partch: summarize dpol
*by partch: summarize dpol if small==1
*by partch: summarize dpol if medium==1
*by partch: summarize dpol if large==1
*by partch: summarize dpol if vlarge==1

*sort unified
*by unified: summarize dpol 
*by unified: summarize dpol if small==1
*by unified: summarize dpol if medium==1
*by unified: summarize dpol if large==1
*by unified: summarize dpol if vlarge==1

*sort reppres
*by reppres: summarize dpol if demdept==1
*by reppres: summarize dpol if demdept==1&small==1
*by reppres: summarize dpol if demdept==1&medium==1
*by reppres: summarize dpol if demdept==1&large==1
*by reppres: summarize dpol if demdept==1&vlarge==1

*With preference measures
sort agencyid year
generate abpres=abs(prescom-prescom[_n-1])
generate presprefs=aprefs*prescom
generate preslib=prescom*liberal
generate prescon=prescom*conservative

*hist dpol
*Here are the basic models.

*I need to take the log of appointees
generate lntotalpa=ln(totalpa)
generate lntotalpap=ln(totalpa+1)
generate lnmgr2=ln(managers2)
generate trend=year-1988

*Here are the wages. Compare weekly average SES wages to comparable private sector wages which is 99th percentile median
*household income. This is all in 1982 dollars.

generate wagediff=(wklyavgses1982- ptile99)/ wklyavgses1982

*The primary models are listed below, one with party measures and one with preference measures.  One difficulty here is
*that variables that only vary by time are highly correlated with each other. I estimate models of them independently
*below but it is difficult to know what is the proper main specification.

more

*FULL SPECIFICATIONS
*NOW BY THE TABLES IN THE CHAPTER
*Table 1. Models replicating the analysis from chapater 3
xtpcse d.lntotalpap d.partch l.partch d.uni l.uni l.lntotalpap d.lnman l.lnman d.lnemp l.lnemp d.reppres l.reppres eop com notitle5 sen ind otherb l.lnty trend, pairwise
xtpcse d.lnpasp d.partch l.partch d.uni l.uni l.lnpasp d.lnman l.lnman d.lnemp l.lnemp d.reppres l.reppres eop com notitle5 sen ind otherb l.lnty trend, pairwise
xtpcse d.lnncp d.partch l.partch d.uni l.uni l.lnncp d.lnman l.lnman d.lnemp l.lnemp d.reppres l.reppres eop com notitle5 sen ind otherb l.lnty trend if sen~=1, pairwise
xtpcse d.lnschcp d.partch l.partch d.uni l.uni l.lnschcp d.lnman l.lnman d.lnemp l.lnemp d.reppres l.reppres eop com notitle5 sen ind otherb l.lnty trend, pairwise

*Table 2. Now models using new measures from OPM data
xtpcse d.lnpasp d.techpct l.techpct d.profpct l.profpct d.prdist l.prdist d.prescom l.prescom aprefs d.prespref l.prespref l.lnpasp d.lnman l.lnman d.lnemp l.lnemp eop com notitle5 sen ind otherb l.lnty trend, pairwise
xtpcse d.lnpasp d.techpct l.techpct d.profpct l.profpct d.prdist l.prdist d.prescom l.prescom conservative liberal d.prescon l.prescon d.preslib l.preslib l.lnpasp d.lnman l.lnman d.lnemp l.lnemp eop com notitle5 sen ind otherb l.lnty trend, pairwise
xtpcse d.lnncp d.techpct l.techpct d.profpct l.profpct d.prdist l.prdist d.prescom l.prescom conservative liberal d.prescon l.prescon d.preslib l.preslib l.lnncp d.lnman l.lnman d.lnemp l.lnemp eop com notitle5 sen ind otherb l.lnty trend if sen~=1, pairwise
xtpcse d.lnschcp d.techpct l.techpct d.profpct l.profpct d.prdist l.prdist d.prescom l.prescom conservative liberal d.prescon l.prescon d.preslib l.preslib l.lnschcp d.lnman l.lnman d.lnemp l.lnemp eop com notitle5 sen ind otherb l.lnty trend, pairwise

**Other models estimated for robustness.
*Models with policy change from last president. I strip these down some to account for collinearity given limited number of years.
xtpcse d.lnpasp d.presdiff l.presdiff d.techpct l.techpct d.profpct l.profpct d.prdist l.prdist d.prescom l.prescom aprefs d.prespref l.prespref l.lnpasp d.lnman l.lnman d.lnemp l.lnemp eop com notitle5 sen ind otherb l.lnty trend, pairwise
xtpcse d.lnpasp d.presdiff l.presdiff d.techpct l.techpct d.profpct l.profpct d.prdist l.prdist d.prescom l.prescom conservative liberal d.prescon l.prescon d.preslib l.preslib l.lnpasp d.lnman l.lnman d.lnemp l.lnemp eop com notitle5 sen ind otherb l.lnty trend, pairwise
xtpcse d.lnncp d.presdiff l.presdiff d.techpct l.techpct d.profpct l.profpct d.prdist l.prdist d.prescom l.prescom conservative liberal d.prescon l.prescon d.preslib l.preslib l.lnncp d.lnman l.lnman d.lnemp l.lnemp eop com notitle5 sen ind otherb l.lnty trend if sen~=1, pairwise
xtpcse d.lnschcp d.presdiff l.presdiff d.techpct l.techpct d.profpct l.profpct d.prdist l.prdist d.prescom l.prescom conservative liberal d.prescon l.prescon d.preslib l.preslib l.lnschcp d.lnman l.lnman d.lnemp l.lnemp eop com notitle5 sen ind otherb l.lnty trend, pairwise

*Now with wage differences-99
xtpcse d.lnpasp d.wage l.wage d.techpct l.techpct d.profpct l.profpct aprefs l.lnpasp d.lnman l.lnman d.lnemp l.lnemp eop com notitle5 sen ind otherb l.lnty trend d.new, pairwise
xtpcse d.lnpasp d.wage l.wage d.techpct l.techpct d.profpct l.profpct aprefs l.lnpasp d.lnman l.lnman d.lnemp l.lnemp eop com notitle5 sen ind otherb l.lnty trend d.new, pairwise
xtpcse d.lnncp d.wage l.wage d.techpct l.techpct d.profpct l.profpct aprefs l.lnncp d.lnman l.lnman d.lnemp l.lnemp eop com notitle5 sen ind otherb l.lnty trend d.new if sen~=1, pairwise
xtpcse d.lnschcp d.wage l.wage d.techpct l.techpct d.profpct l.profpct aprefs l.lnschcp d.lnman l.lnman d.lnemp l.lnemp eop com notitle5 sen ind otherb l.lnty trend d.new, pairwise

*White House Office
xtpcse d.lnpasp d.techpct l.techpct d.profpct l.profpct d.prdist l.prdist d.prescom l.prescom aprefs d.prespref l.prespref l.lnpasp d.lnman l.lnman d.lnemp l.lnemp eop com notitle5 sen ind otherb l.lnty trend d.whstaff l.whstaff, pairwise
xtpcse d.lnpasp d.techpct l.techpct d.profpct l.profpct d.prdist l.prdist d.prescom l.prescom conservative liberal d.prescon l.prescon d.preslib l.preslib l.lnpasp d.lnman l.lnman d.lnemp l.lnemp eop com notitle5 sen ind otherb l.lnty trend d.whstaff l.whstaff, pairwise
xtpcse d.lnncp d.techpct l.techpct d.profpct l.profpct d.prdist l.prdist d.prescom l.prescom conservative liberal d.prescon l.prescon d.preslib l.preslib l.lnncp d.lnman l.lnman d.lnemp l.lnemp eop com notitle5 sen ind otherb l.lnty trend d.whstaff l.whstaff if sen~=1, pairwise
xtpcse d.lnschcp d.techpct l.techpct d.profpct l.profpct d.prdist l.prdist d.prescom l.prescom conservative liberal d.prescon l.prescon d.preslib l.preslib l.lnschcp d.lnman l.lnman d.lnemp l.lnemp eop com notitle5 sen ind otherb l.lnty trend d.whstaff l.whstaff, pairwise

*Without Otherb
xtpcse d.lnpasp d.techpct l.techpct d.profpct l.profpct d.prdist l.prdist d.prescom l.prescom aprefs d.prespref l.prespref l.lnpasp d.lnman l.lnman d.lnemp l.lnemp eop com notitle5 sen ind otherb l.lnty trend if otherb==0, pairwise
xtpcse d.lnpasp d.techpct l.techpct d.profpct l.profpct d.prdist l.prdist d.prescom l.prescom conservative liberal d.prescon l.prescon d.preslib l.preslib l.lnpasp d.lnman l.lnman d.lnemp l.lnemp eop com notitle5 sen ind otherb l.lnty trend if otherb==0, pairwise
xtpcse d.lnncp d.techpct l.techpct d.profpct l.profpct d.prdist l.prdist d.prescom l.prescom conservative liberal d.prescon l.prescon d.preslib l.preslib l.lnncp d.lnman l.lnman d.lnemp l.lnemp eop com notitle5 sen ind otherb l.lnty trend if sen~=1&otherb==0, pairwise
xtpcse d.lnschcp d.techpct l.techpct d.profpct l.profpct d.prdist l.prdist d.prescom l.prescom conservative liberal d.prescon l.prescon d.preslib l.preslib l.lnschcp d.lnman l.lnman d.lnemp l.lnemp eop com notitle5 sen ind otherb l.lnty trend if otherb==0, pairwise

*Now including lnscha
xtpcse d.lnpasp d.techpct l.techpct d.profpct l.profpct d.prdist l.prdist d.prescom l.prescom aprefs d.prespref l.prespref l.lnpasp d.lnman l.lnman d.lnemp l.lnemp eop com notitle5 sen ind otherb l.lnty trend d.lnscha l.lnscha, pairwise
xtpcse d.lnpasp d.techpct l.techpct d.profpct l.profpct d.prdist l.prdist d.prescom l.prescom conservative liberal d.prescon l.prescon d.preslib l.preslib l.lnpasp d.lnman l.lnman d.lnemp l.lnemp eop com notitle5 sen ind otherb l.lnty trend d.lnscha l.lnscha, pairwise
xtpcse d.lnncp d.techpct l.techpct d.profpct l.profpct d.prdist l.prdist d.prescom l.prescom conservative liberal d.prescon l.prescon d.preslib l.preslib l.lnncp d.lnman l.lnman d.lnemp l.lnemp eop com notitle5 sen ind otherb l.lnty trend d.lnscha l.lnscha if sen~=1, pairwise
xtpcse d.lnschcp d.techpct l.techpct d.profpct l.profpct d.prdist l.prdist d.prescom l.prescom conservative liberal d.prescon l.prescon d.preslib l.preslib l.lnschcp d.lnman l.lnman d.lnemp l.lnemp eop com notitle5 sen ind otherb l.lnty trend d.lnscha l.lnscha, pairwise

*Without EOP Agencies
xtpcse d.lnpasp d.techpct l.techpct d.profpct l.profpct d.prdist l.prdist d.prescom l.prescom aprefs d.prespref l.prespref l.lnpasp d.lnman l.lnman d.lnemp l.lnemp eop com notitle5 sen ind otherb l.lnty trend if eop==0, pairwise
xtpcse d.lnpasp d.techpct l.techpct d.profpct l.profpct d.prdist l.prdist d.prescom l.prescom conservative liberal d.prescon l.prescon d.preslib l.preslib l.lnpasp d.lnman l.lnman d.lnemp l.lnemp eop com notitle5 sen ind otherb l.lnty trend if eop==0, pairwise
xtpcse d.lnncp d.techpct l.techpct d.profpct l.profpct d.prdist l.prdist d.prescom l.prescom conservative liberal d.prescon l.prescon d.preslib l.preslib l.lnncp d.lnman l.lnman d.lnemp l.lnemp eop com notitle5 sen ind otherb l.lnty trend if sen~=1&eop==0, pairwise
xtpcse d.lnschcp d.techpct l.techpct d.profpct l.profpct d.prdist l.prdist d.prescom l.prescom conservative liberal d.prescon l.prescon d.preslib l.preslib l.lnschcp d.lnman l.lnman d.lnemp l.lnemp eop com notitle5 sen ind otherb l.lnty trend if eop==0, pairwise

*Without agencies with own personnel systems or without SES.
xtpcse d.lnpasp d.techpct l.techpct d.profpct l.profpct d.prdist l.prdist d.prescom l.prescom aprefs d.prespref l.prespref l.lnpasp d.lnman l.lnman d.lnemp l.lnemp eop com notitle5 sen ind otherb l.lnty trend if notitle==0&sen~=1, pairwise
xtpcse d.lnpasp d.techpct l.techpct d.profpct l.profpct d.prdist l.prdist d.prescom l.prescom conservative liberal d.prescon l.prescon d.preslib l.preslib l.lnpasp d.lnman l.lnman d.lnemp l.lnemp eop com notitle5 sen ind otherb l.lnty trend if notitle==0&sen~=1, pairwise
xtpcse d.lnncp d.techpct l.techpct d.profpct l.profpct d.prdist l.prdist d.prescom l.prescom conservative liberal d.prescon l.prescon d.preslib l.preslib l.lnncp d.lnman l.lnman d.lnemp l.lnemp eop com notitle5 sen ind otherb l.lnty trend if notitle==0&sen~=1, pairwise
xtpcse d.lnschcp d.techpct l.techpct d.profpct l.profpct d.prdist l.prdist d.prescom l.prescom conservative liberal d.prescon l.prescon d.preslib l.preslib l.lnschcp d.lnman l.lnman d.lnemp l.lnemp eop com notitle5 sen ind otherb l.lnty trend if notitle==0&sen~=1, pairwise

*Without adding 1 to appointee totals.
xtpcse d.lnpas d.techpct l.techpct d.profpct l.profpct d.prdist l.prdist d.prescom l.prescom aprefs d.prespref l.prespref l.lnpas d.lnman l.lnman d.lnemp l.lnemp eop com notitle5 sen ind otherb l.lnty trend, pairwise
xtpcse d.lnpas d.techpct l.techpct d.profpct l.profpct d.prdist l.prdist d.prescom l.prescom conservative liberal d.prescon l.prescon d.preslib l.preslib l.lnpas d.lnman l.lnman d.lnemp l.lnemp eop com notitle5 sen ind otherb l.lnty trend, pairwise
xtpcse d.lnnc d.techpct l.techpct d.profpct l.profpct d.prdist l.prdist d.prescom l.prescom conservative liberal d.prescon l.prescon d.preslib l.preslib l.lnnc d.lnman l.lnman d.lnemp l.lnemp eop com notitle5 sen ind otherb l.lnty trend if sen~=1, pairwise
xtpcse d.lnschc d.techpct l.techpct d.profpct l.profpct d.prdist l.prdist d.prescom l.prescom conservative liberal d.prescon l.prescon d.preslib l.preslib l.lnschc d.lnman l.lnman d.lnemp l.lnemp eop com notitle5 sen ind otherb l.lnty trend, pairwise

*SUREG Models
sureg(d.lnpasp d.techpct l.techpct d.profpct l.profpct d.prdist l.prdist d.prescom l.prescom conservative liberal d.prescon l.prescon d.preslib l.preslib l.lnpasp d.lnman l.lnman d.lnemp l.lnemp eop com notitle5 sen ind otherb l.lnty trend)(d.lnncp d.techpct l.techpct d.profpct l.profpct d.prdist l.prdist d.prescom l.prescom conservative liberal d.prescon l.prescon d.preslib l.preslib l.lnncp d.lnman l.lnman d.lnemp l.lnemp eop com notitle5 sen ind otherb l.lnty trend)(d.lnschcp d.techpct l.techpct d.profpct l.profpct d.prdist l.prdist d.prescom l.prescom conservative liberal d.prescon l.prescon d.preslib l.preslib l.lnschcp d.lnman l.lnman d.lnemp l.lnemp eop com notitle5 sen ind otherb l.lnty trend)


